@@ -1,5 +1,8 @@
 from .dataframe import StockDataFrame
-from .directive import DirectiveCache
+from .directive import (
+    DirectiveCache,
+    directive_stringify
+)
 
 from .exceptions import (
     DirectiveSyntaxError,
@@ -10,3 +13,9 @@ from .commands import (
     COMMANDS,
     CommandPreset
 )
+
+from .meta import (
+    TimeFrame,
+    TimeFrameArg,
+    cumulators
+)
