@@ -3,11 +3,16 @@ import itertools
 import pytest
 import pandas as pd
 
-from stock_pandas import StockDataFrame
+from stock_pandas import (
+    StockDataFrame,
+    directive_stringify
+)
+
 from .common import (
     simple_list,
     create_stock,
-    get_stock_update
+    get_stock_update,
+    get_tencent
 )
 
 
@@ -18,6 +23,7 @@ def stock():
 
 def test_directive_stringify(stock: StockDataFrame):
     assert stock.directive_stringify('boll') == 'boll:20,close'
+    assert directive_stringify('boll') == 'boll:20,close'
 
 
 def test_get_column(stock):
@@ -108,8 +114,12 @@ def test_period_larger_than_size(stock):
 
 def test_aliases(stock):
     stock.alias('Open', 'open')
+
     assert list(stock['Open']) == simple_list
 
+    dropped = stock.drop(columns=['close'])
+    assert list(dropped['Open']) == simple_list
+
     with pytest.raises(ValueError, match='not exists'):
         stock.alias('some_column', 'not-exists')
 
@@ -136,3 +146,21 @@ def test_multi_index():
             index=['A', 'B', 'C'],
             columns=columns
         )
+
+
+def test_date_col_pollution_issue_21():
+    csv = get_tencent(stock=False)
+
+    StockDataFrame(csv, date_col='time_key')
+
+    with pytest.raises(KeyError, match='time_key'):
+        csv['time_key']
+
+    csv = get_tencent(stock=False)
+
+    StockDataFrame(csv, date_col='time_key', copy=True)
+
+    try:
+        csv['time_key']
+    except Exception as e:
+        raise RuntimeError(f'date_col should not change the original dataframe, error: {e}')
